cvs: peardoc / .cvsignore configure.php /scripts pearwebbuild.php pearwebpackagetocs.php

[email protected] ("Christian Weiske")
Newsgroups php.pear.doc
Message-ID <cvscweiske1233182630@cvsserver>
cweiske		Wed Jan 28 22:43:50 2009 UTC

  Modified files:              
    /peardoc	configure.php .cvsignore 
    /peardoc/scripts	pearwebbuild.php pearwebpackagetocs.php 
  Log:
  Switch to .manual.xml instead of giant.xml.
  We're doing it the same way as phpdoc now.
  
  
http://cvs.php.net/viewvc.cgi/peardoc/configure.php?r1=1.8&r2=1.9&diff_format=u
Index: peardoc/.cvsignore
diff -u peardoc/.cvsignore:1.9 peardoc/.cvsignore:1.10
--- peardoc/.cvsignore:1.9	Wed Nov 12 21:02:22 2008
+++ peardoc/.cvsignore	Wed Jan 28 22:43:50 2009
@@ -1,4 +1,4 @@
 .*.ser
 build
 chapters.ent
-giant.xml
+.manual.xml
\ No newline at end of file
http://cvs.php.net/viewvc.cgi/peardoc/scripts/pearwebbuild.php?r1=1.14&r2=1.15&diff_format=u
Index: peardoc/scripts/pearwebbuild.php
diff -u peardoc/scripts/pearwebbuild.php:1.14 peardoc/scripts/pearwebbuild.php:1.15
--- peardoc/scripts/pearwebbuild.php:1.14	Wed Jan 28 15:56:17 2009
+++ peardoc/scripts/pearwebbuild.php	Wed Jan 28 22:43:50 2009
@@ -22,7 +22,7 @@
 require_once 'Console/CommandLine.php';
 $parser = new Console_CommandLine();
 $parser->description = 'Builds the full manual';
-$parser->version = '$Id: pearwebbuild.php,v 1.14 2009/01/28 15:56:17 izi Exp $';
+$parser->version = '$Id: pearwebbuild.php,v 1.15 2009/01/28 22:43:50 cweiske Exp $';
 $parser->addOption('updatecvs', array(
     'long_name'   => '--updatecvs',
     'description' => 'Update peardoc from CVS',
@@ -93,7 +93,7 @@
 
         //bightml
         logAndEcho(' Rendering and bzipping pearbightml downloadable file');
-        shell_exec("$phd_executable -f xhtml -t pearbightml -o build/$lang -d giant.xml" . $tobuildlog);
+        shell_exec("$phd_executable -f xhtml -t pearbightml -o build/$lang -d .manual.xml" . $tobuildlog);
 
         // bzip2
         passthru('bzip2'
@@ -120,7 +120,7 @@
 
         //chunkedhtml
         logAndEcho(' Rendering and bzipping pearchunked downloadable zip');
-        shell_exec("$phd_executable -f xhtml -t pearchunkedhtml -o build/$lang -d giant.xml" . $tobuildlog);
+        shell_exec("$phd_executable -f xhtml -t pearchunkedhtml -o build/$lang -d .manual.xml" . $tobuildlog);
 
         // tar.bz2
         passthru(
@@ -148,7 +148,7 @@
         );
 
         //pearweb
-        shell_exec("$phd_executable -f xhtml -t pearweb -o build/$lang -d giant.xml" . $tobuildlog);
+        shell_exec("$phd_executable -f xhtml -t pearweb -o build/$lang -d .manual.xml" . $tobuildlog);
 
 
         //pearweb package tocs
@@ -194,7 +194,7 @@
         }
 
         // Remove chm build until we can get a chm compiler going.
-        //shell_exec("$phd_executable -f xhtml -t pearchm -o build/$lang -d giant.xml" . $tobuildlog);
+        //shell_exec("$phd_executable -f xhtml -t pearchm -o build/$lang -d .manual.xml" . $tobuildlog);
 
         logAndEcho(" Finished peardoc/$lang");
     } else {
http://cvs.php.net/viewvc.cgi/peardoc/scripts/pearwebpackagetocs.php?r1=1.2&r2=1.3&diff_format=u
Index: peardoc/scripts/pearwebpackagetocs.php
diff -u peardoc/scripts/pearwebpackagetocs.php:1.2 peardoc/scripts/pearwebpackagetocs.php:1.3
--- peardoc/scripts/pearwebpackagetocs.php:1.2	Fri Jan  2 14:23:01 2009
+++ peardoc/scripts/pearwebpackagetocs.php	Wed Jan 28 22:43:50 2009
@@ -23,7 +23,7 @@
     require_once 'Console/CommandLine.php';
     $parser = new Console_CommandLine(array(
         'description' => 'Create package TOC files for pearweb',
-        'version'     => '$Id: pearwebpackagetocs.php,v 1.2 2009/01/02 14:23:01 cweiske Exp $'
+        'version'     => '$Id: pearwebpackagetocs.php,v 1.3 2009/01/28 22:43:50 cweiske Exp $'
     ));
 
     $parser->addOption('verbose', array(
@@ -38,7 +38,7 @@
         'long_name'   => '--giant',
         'action'      => 'StoreString',
         'description' => 'File name of merged (giant) manual',
-        'default'     => 'giant.xml',
+        'default'     => '.manual.xml',
     ));
     $parser->addOption('index_file', array(
         'short_name'  => '-i',
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.
Index: peardoc/configure.php
diff -u peardoc/configure.php:1.8 peardoc/configure.php:1.9
--- peardoc/configure.php:1.8	Sun Jan 25 11:56:05 2009
+++ peardoc/configure.php	Wed Jan 28 22:43:49 2009
@@ -4,7 +4,7 @@
 * Configure the manual:
 * - select language
 * - create chapters.ent listing all files
-* - create the giant.xml file (much faster than using manual.xml and
+* - create the giant .manual.xml file (much faster than using manual.xml and
 *    pulling in single files)
 * - validate the manual against Docbook 5 DTD
 *
@@ -47,7 +47,7 @@
     require_once 'Console/CommandLine.php';
     $parser = new Console_CommandLine(array(
         'description' => 'configure the pear manual build',
-        'version'     => '$Id: configure.php,v 1.8 2009/01/25 11:56:05 cweiske Exp $'
+        'version'     => '$Id: configure.php,v 1.9 2009/01/28 22:43:49 cweiske Exp $'
     ));
 
     $parser->addOption('verbose', array(
@@ -61,7 +61,7 @@
         'short_name'  => '-n',
         'long_name'   => '--no-validate',
         'action'      => 'StoreFalse',
-        'description' => 'Validate the giant.xml file',
+        'description' => 'Validate the giant .manual.xml file',
         'default'     => true
     ));
     $parser->addOption('giant_file', array(
@@ -69,7 +69,7 @@
         'long_name'   => '--output',
         'action'      => 'StoreString',
         'description' => 'File name of merged (giant) manual',
-        'default'     => 'giant.xml'
+        'default'     => '.manual.xml'
     ));
     $parser->addOption('display_untranslated', array(
         'long_name'   => '--no-display-untranslated',
@@ -227,7 +227,7 @@
 
 /**
 * Create one giant xml file by incluing every entity into manual.xml
 * and saving it as giant.xml
 *
 * @param string  $strGiant    Name of merged (giant) xml file
 * @param boolean $bValidate   If the generated manual shall be validated
@@ -238,7 +238,7 @@
 *
 * @return void
 */
-function createGiant($strGiant = 'giant.xml', $bValidate = false, $bHideErrors = true)
+function createGiant($strGiant = '.manual.xml', $bValidate = false, $bHideErrors = true)
 {
     logMsg('Loading manual into one giant file');
     $dom = new DOMDocument();
@@ -275,7 +275,7 @@
     if (!$bValid) {
         logMsg('  Manual has errors. Use');
         logMsg('   xmllint --valid --noout manual.xml');
-        logMsg('   xmllint --valid --noout giant.xml');
+        logMsg('   xmllint --valid --noout .manual.xml');
         logMsg('  to get detailled error messages.');
         $GLOBALS['errorcode'] = 5;
     }
@@ -227,7 +227,7 @@
 /**
 * Create one giant xml file by incluing every entity into manual.xml
-* and saving it as giant.xml
+* and saving it as .manual.xml
 *
 * @param string  $strGiant    Name of merged (giant) xml file
http://cvs.php.net/viewvc.cgi/peardoc/.cvsignore?r1=1.9&r2=1.10&diff_format=u